# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import

import datetime
import logging

from django.core.management import BaseCommand
from django.utils.timezone import now

from django_cbrf.utils import get_cbrf_model
from ...settings import DAYS_FOR_POPULATE

logger = logging.getLogger(__name__)

Currency = get_cbrf_model('Currency')
Record = get_cbrf_model('Record')


class Command(BaseCommand):
    """ Load currency rate records frim cbr.ru """

    help = """ 
Download rates for selected currencies from today back to today minus '--days' argument value.

For example, command like:

    `manage.py load_rates USD RUB --days 90`
    
will populate rates for $ and ₽ for last 90 days.
    """

    def add_arguments(self, parser):
        parser.add_argument('iso_codes', nargs='+', type=str)
        parser.add_argument('--days', type=int, default=DAYS_FOR_POPULATE)

    def handle(self, *args, **options):
        days = options['days']
        currencies = options['iso_codes']

        if not Currency.objects.all():
            logger.info("No one Currency in DB. Populating...")
            Currency.populate()

        date_1 = now().date() - datetime.timedelta(days=days)
        date_2 = now().date()

        for currency_iso in currencies:
            currency = Currency.get_by_iso_char_code(currency_iso.upper())
            if currency:
                logger.info("Get rates for '{}'".format(currency.eng_name))
                Record.populate_for_dates(date_1, date_2, currency)
            else:
                logger.error("Currency with '{}' ISO code is not exist. Skipped.".format(currency_iso))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import

import logging

from django.core.management import BaseCommand
from django.db import IntegrityError

from django_cbrf.utils import get_cbrf_model

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    """ Load currencies and retes from cbr.ru according settings
    """
    help = """
Download all currencies and save them in DB

To force populate use:

    manage.py load_currencies --force
    """

    def add_arguments(self, parser):
        parser.add_argument('-f', '--force', action='store_true', default=False,
                            help='Populate Currencies even they already exist')

    def handle(self, *args, **options):
        Currency = get_cbrf_model('Currency')

        force = options.get('force', False)

        if not force:
            try:
                Currency.populate()
            except IntegrityError:
                logger.error('Abort. Looks like Currencies already populated. '
                             'To force populate use "python manage.py load_currencies --force"')
                raise IntegrityError(
                    'Currencies already populated. '
                    'To force populate use "python manage.py load_currencies --force"'
                )
        else:
            Currency.populate(force=True)

        logger.info('Done. Currencies was populated.')



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-01 09:51
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cbrf_id', models.CharField(db_index=True, max_length=12, unique=True, verbose_name='CB RF code')),
                ('parent_code', models.CharField(max_length=6, verbose_name='parent code')),
                ('name', models.CharField(max_length=64, verbose_name='name')),
                ('eng_name', models.CharField(max_length=64, verbose_name='english name')),
                ('denomination', models.SmallIntegerField(default=1, verbose_name='denomination')),
                ('iso_num_code', models.SmallIntegerField(blank=True, default=None, null=True, verbose_name='ISO numeric code')),
                ('iso_char_code', models.CharField(blank=True, db_index=True, default=None, max_length=3, null=True, verbose_name='ISO char code')),
            ],
            options={
                'verbose_name': 'currency',
                'verbose_name_plural': 'currencies',
                'ordering': ('cbrf_id',),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Record',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField()),
                ('value', models.DecimalField(decimal_places=4, max_digits=9, verbose_name='value')),
                ('currency', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='django_cbrf_record', to='django_cbrf.Currency')),
            ],
            options={
                'verbose_name': 'record',
                'verbose_name_plural': 'records',
                'abstract': False,
            },
        ),
        migrations.AlterUniqueTogether(
            name='record',
            unique_together=set([('date', 'currency')]),
        ),
    ]
